@@ -7,12 +7,12 @@ import os
 from pathlib import Path
 
 from ._fetching import fetch_file, _hashfunc
-from .. import logger
+from ..utils._logs import logger
 
 
 MD5 = '8925f81af22390fd17bb3341d553430f'
 SHA1 = '65dbf592fa6e18cee049f244ca53c504ddabacc1'
-URL = 'https://github.com/bsl-tools/bsl-datasets/raw/main/eeg_sample/resting_state-raw.fif'
+URL = 'https://github.com/bsl-tools/bsl-datasets/raw/main/eeg_sample/resting_state-raw.fif'  # noqa: E501
 PATH = Path('~/bsl_data/eeg_sample/resting_state-raw.fif').expanduser()
 
 
@@ -22,6 +22,11 @@ def data_path():
     electrodes. This is a resting-state recording lasting 40 seconds.
     If the dataset is not locally present, it is downloaded in the user home
     directory in the folder ``bsl_data/eeg_sample``.
+
+    Returns
+    -------
+    path : Path
+        Path to the dataset.
     """
     os.makedirs(PATH.parent, exist_ok=True)
 
