@@ -7,12 +7,12 @@ import os
 from pathlib import Path
 
 from ._fetching import fetch_file, _hashfunc
-from .. import logger
+from ..utils._logs import logger
 
 
 MD5 = 'e808b98c464f6d28d0343a054f35c13e'
 SHA1 = 'd14dc86d799e6b140d88643282f4229187caa34e'
-URL = 'https://github.com/bsl-tools/bsl-datasets/raw/main/eeg_sample/resting_state_short-raw.fif'
+URL = 'https://github.com/bsl-tools/bsl-datasets/raw/main/eeg_sample/resting_state_short-raw.fif'  # noqa: E501
 PATH = Path('~/bsl_data/eeg_sample/resting_state_short-raw.fif').expanduser()
 
 
@@ -22,6 +22,11 @@ def data_path():
     electrodes. This is a resting-state recording lasting 2 seconds.
     If the dataset is not locally present, it is downloaded in the user home
     directory in the folder ``bsl_data/eeg_sample``.
+
+    Returns
+    -------
+    path : Path
+        Path to the dataset.
     """
     os.makedirs(PATH.parent, exist_ok=True)
 
