@@ -1,12 +1,12 @@
 import pytest
 
 from bsl.datasets._fetching import fetch_file
-from bsl.utils._testing import requires_good_network
+from bsl.utils._tests import requires_good_network
 
 
-URL = 'https://raw.githubusercontent.com/bsl-tools/bsl/master/README.md'
-HASH = {'md5': '665cfaaaed5ed3cbffbabe0f482f0ec3',
-        'sha1': '625fde952c1641def40879caba95cadce5543ffe'}
+URL = 'https://raw.githubusercontent.com/bsl-tools/bsl/master/LICENSE'
+HASH = {'md5': '1803fa9c2c3ce8cb06b4861d75310742',
+        'sha1': 'b386b371ce94933e63ced1052aa72a60da5485ff'}
 WRONG_HASH = {'md5': '12345678912345678912345678912345',
               'sha1': '1234567891234567891234567891234567891234'}
 
