@@ -1,25 +1,30 @@
 """
-Sample trigger definition .ini file.
+Sample trigger definition ``.ini`` file.
 """
 
 import os
 from pathlib import Path
 
 from ._fetching import fetch_file, _hashfunc
-from .. import logger
+from ..utils._logs import logger
 
 
 MD5 = '553f24ecb5c8e67ebe597e6e71d7fcdc'
 SHA1 = 'b841bbba374586434916e70403703388fc67ac74'
-URL = 'https://github.com/bsl-tools/bsl-datasets/raw/main/trigger_def/trigger_def.ini'
+URL = 'https://github.com/bsl-tools/bsl-datasets/raw/main/trigger_def/trigger_def.ini'  # noqa: E501
 PATH = Path('~/bsl_data/trigger_def/trigger_def.ini').expanduser()
 
 
 def data_path():
     """
-    Return the path to an example trigger definition .ini file.
+    Return the path to an example trigger definition ``.ini`` file.
     If the dataset is not locally present, it is downloaded in the user home
     directory in the folder ``bsl_data/trigger_def``.
+
+    Returns
+    -------
+    path : Path
+        Path to the dataset.
     """
     os.makedirs(PATH.parent, exist_ok=True)
 
