@@ -7,7 +7,7 @@ import numpy as np
 
 from bsl import StreamReceiver, StreamPlayer, logger, set_log_level
 from bsl.datasets import eeg_resting_state
-from bsl.utils._testing import requires_eeg_resting_state_dataset
+from bsl.utils._tests import requires_eeg_resting_state_dataset
 
 
 set_log_level('INFO')
@@ -161,7 +161,8 @@ def test_properties():
         assert sr.winsize == sr._winsize == 0.2
         assert sr.bufsize == sr._bufsize == 1
         assert sr.stream_name is None
-        assert sr.connected == sr._connected == True
+        assert sr.connected == sr._connected
+        assert sr.connected
         assert sr.mne_infos == sr._mne_infos
         assert isinstance(sr.mne_infos, dict)
         assert len(sr.mne_infos) == 1
@@ -201,8 +202,8 @@ def test_get_method_warning_and_errors(caplog):
         # Disconnect and acquire
         sr.disconnect()
         with pytest.raises(RuntimeError,
-                            match='StreamReceiver is not connected to any '
-                                  'streams.'):
+                           match='StreamReceiver is not connected to any '
+                                 'streams.'):
             sr.acquire()
 
         # Acquire, disconnect and get.
@@ -212,12 +213,12 @@ def test_get_method_warning_and_errors(caplog):
         time.sleep(0.05)
         sr.disconnect()
         with pytest.raises(RuntimeError,
-                            match='StreamReceiver is not connected to any '
-                                  'streams.'):
+                           match='StreamReceiver is not connected to any '
+                           'streams.'):
             sr.get_window()
         with pytest.raises(RuntimeError,
-                            match='StreamReceiver is not connected to any '
-                                  'streams.'):
+                           match='StreamReceiver is not connected to any '
+                                 'streams.'):
             sr.get_buffer()
 
         # multiple streams
@@ -225,14 +226,14 @@ def test_get_method_warning_and_errors(caplog):
         time.sleep(1)
         sr.acquire()
         with pytest.raises(RuntimeError,
-                            match='StreamReceiver is connected to multiple '
-                                  'streams. Please provide the stream_name '
-                                  'argument.'):
+                           match='StreamReceiver is connected to multiple '
+                                 'streams. Please provide the stream_name '
+                                 'argument.'):
             sr.get_window()
         with pytest.raises(RuntimeError,
-                            match='StreamReceiver is connected to multiple '
-                                  'streams. Please provide the stream_name '
-                                  'argument.'):
+                           match='StreamReceiver is connected to multiple '
+                                 'streams. Please provide the stream_name '
+                                 'argument.'):
             sr.get_buffer()
 
         # stream_name not in streams
@@ -346,15 +347,14 @@ def test_checker_bufsize(caplog):
 
         # Invalid value
         with pytest.raises(ValueError,
-                            match='Argument bufsize must be a strictly positive'
-                                  ' int or a float. Provided: %s' % -5):
-            StreamReceiver(bufsize=-5, winsize=0.2)
+                           match='Argument bufsize must be a strictly'
+                                 ' positive int or a float. '
+                                 'Provided: %s' % -101):
+            StreamReceiver(bufsize=-101, winsize=0.2)
 
         # Invalid type
-        with pytest.raises(TypeError,
-                            match='Argument bufsize must be a strictly positive'
-                                  ' int or a float. Provided: %s' % type([1])):
-            StreamReceiver(bufsize=[1], winsize=0.2)
+        with pytest.raises(TypeError, match="'bufsize' must be an instance"):
+            StreamReceiver(bufsize=[101], winsize=0.2)
 
         # Smaller than winsize
         caplog.clear()
@@ -382,14 +382,12 @@ def test_checker_winsize():
         # Invalid value
         with pytest.raises(ValueError,
                            match='Argument winsize must be a strictly positive'
-                                 ' int or a float. Provided: %s' % -5):
-            StreamReceiver(bufsize=1, winsize=-5)
+                                 ' int or a float. Provided: %s' % -101):
+            StreamReceiver(bufsize=1, winsize=-101)
 
         # Invalid type
-        with pytest.raises(TypeError,
-                           match='Argument winsize must be a strictly positive'
-                                 ' int or a float. Provided: %s' % type([1])):
-            StreamReceiver(bufsize=1, winsize=[1])
+        with pytest.raises(TypeError, match="'winsize' must be an instance"):
+            StreamReceiver(bufsize=1, winsize=[101])
 
 
 @requires_eeg_resting_state_dataset
@@ -412,20 +410,23 @@ def test_checker_stream_name(caplog):
         assert sr.stream_name == ['StreamPlayer']
         del sr
 
+        # Valid - tuple of str
+        sr = StreamReceiver(bufsize=1, winsize=0.2,
+                            stream_name=('StreamPlayer', ))
+        assert sr.stream_name == ['StreamPlayer']
+        del sr
+
         # Invalid - list of 'not str'
         with pytest.raises(TypeError,
                            match=re.escape(
                                'Argument stream_name must be a string or a '
-                               'list of strings. Provided: [1, 2]')):
-            StreamReceiver(bufsize=1, winsize=0.2, stream_name=[1, 2])
+                               'list of strings. Provided: [1, 0, 1]')):
+            StreamReceiver(bufsize=1, winsize=0.2, stream_name=[1, 0, 1])
 
         # Invalid type
-        caplog.clear()
-        sr = StreamReceiver(bufsize=1, winsize=0.2, stream_name=5)
-        assert sr.stream_name is None
-        assert ('Argument stream_name must be a string or a list of strings. '
-                'Provided: %s -> Changing to None.' % 5) in caplog.text
-        del sr
+        with pytest.raises(TypeError,
+                           match="'stream_name' must be an instance"):
+            StreamReceiver(bufsize=1, winsize=0.2, stream_name=101)
 
 
 @requires_eeg_resting_state_dataset
