@@ -3,8 +3,9 @@ Base class for triggers.
 """
 from abc import ABC, abstractmethod
 
-from .. import logger
+from ..utils._checks import _check_type
 from ..utils._docs import fill_doc
+from ..utils._logs import logger
 
 
 @fill_doc
@@ -19,7 +20,7 @@ class _Trigger(ABC):
 
     @abstractmethod
     def __init__(self, verbose: bool = True):
-        self._verbose = bool(verbose)
+        self.verbose = verbose
 
     @abstractmethod
     def signal(self, value: int):
@@ -45,4 +46,5 @@ class _Trigger(ABC):
 
     @verbose.setter
     def verbose(self, verbose: bool):
-        self._verbose = bool(verbose)
+        _check_type(verbose, (bool, ), item_name='verbose')
+        self._verbose = verbose
