@@ -1,13 +1,15 @@
 """
 Mock trigger.
 """
+
 from ._trigger import _Trigger
-from .. import logger
+from ..utils._checks import _check_type
 from ..utils._docs import fill_doc, copy_doc
+from ..utils._logs import logger
 
 
 @fill_doc
-class TriggerMock(_Trigger):
+class MockTrigger(_Trigger):
     """
     Mock trigger class.
 
@@ -16,11 +18,12 @@ class TriggerMock(_Trigger):
     %(trigger_verbose)s
     """
 
-    def __init__(self, verbose: bool = True):
+    def __init__(self, *, verbose: bool = True):
         super().__init__(verbose)
 
     @copy_doc(_Trigger.signal)
     def signal(self, value: int) -> bool:
+        _check_type(value, ('int', ), item_name='value')
         self._set_data(value)
         super().signal(value)
         return True
@@ -34,4 +37,4 @@ class TriggerMock(_Trigger):
     @copy_doc(_Trigger._set_data)
     def _set_data(self, value: int):
         super()._set_data(value)
-        logger.info(f'MOCK trigger set to {value}')
+        logger.info('MOCK trigger set to %i', value)
