@@ -4,8 +4,8 @@ import mne
 
 from bsl import StreamRecorder, StreamPlayer
 from bsl.datasets import eeg_resting_state
-from bsl.triggers.software import TriggerSoftware
-from bsl.utils._testing import requires_eeg_resting_state_dataset
+from bsl.triggers import SoftwareTrigger
+from bsl.utils._tests import requires_eeg_resting_state_dataset
 
 
 @requires_eeg_resting_state_dataset
@@ -16,15 +16,18 @@ def test_trigger_software(tmp_path):
                                   stream_name='StreamPlayer', fif_subdir=False)
         recorder.start()
 
-        trigger = TriggerSoftware(recorder, verbose=True)
+        trigger = SoftwareTrigger(recorder, verbose=True)
         assert trigger.verbose
         trigger.verbose = False
+        time.sleep(0.5)
 
         assert trigger.signal(1)
         time.sleep(0.1)
         assert trigger.signal(2)
 
+        time.sleep(0.5)
         trigger.close()
+        time.sleep(0.5)
         recorder.stop()
 
     raw = mne.io.read_raw_fif(tmp_path / 'test-StreamPlayer-raw.fif')
