@@ -8,8 +8,8 @@ import importlib
 # A mapping from import name to package name (on PyPI) when the package name
 # is different.
 INSTALL_MAPPING = {
-    "serial": "pyserial",
-    "cv2": "opencv-python"}
+    "serial": "pyserial"
+    }
 
 
 def import_optional_dependency(
