@@ -1,5 +1,7 @@
 import time
 
+from ._checks import _check_type
+
 
 class Timer:
     """
@@ -7,12 +9,12 @@ class Timer:
 
     Parameters
     ----------
-    autoreset : `bool`
+    autoreset : bool
         If ``autoreset=True``, timer is reset after any member function call.
     """
 
     def __init__(self, autoreset=False):
-        self._autoreset = bool(autoreset)
+        self.autoreset = autoreset
         self.reset()
 
     def sec(self):
@@ -43,7 +45,7 @@ class Timer:
 
         Parameters
         ----------
-        sec : `float`
+        sec : float
             Time to sleep in seconds.
         """
         timer_sec = self.sec()
@@ -58,10 +60,11 @@ class Timer:
         """
         Autoreset status.
 
-        :type: `bool`
+        :type: bool
         """
         return self._autoreset
 
     @autoreset.setter
     def autoreset(self, autoreset):
-        self._autoreset = bool(autoreset)
+        _check_type(autoreset, (bool, ), item_name='autoreset')
+        self._autoreset = autoreset
